@@ -791,7 +791,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::OnColumnRightClicked(wx
 
 template<class CFileData> void CFileListCtrl<CFileData>::InitSort(interfaceOptions optionID)
 {
-	wxString sortInfo = options_.get_string(optionID);
+	std::wstring sortInfo = options_.get_string(optionID);
 	if (!sortInfo.empty()) {
 		m_sortDirection = sortInfo[0] - '0';
 	}
@@ -802,7 +802,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::InitSort(interfaceOptio
 		m_sortDirection = 0;
 	}
 
-	if (sortInfo.Len() == 3) {
+	if (sortInfo.size() == 3) {
 		m_sortColumn = sortInfo[2] - '0';
 		if (GetColumnVisibleIndex(m_sortColumn) == -1) {
 			m_sortColumn = 0;
@@ -878,7 +878,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::OnItemDeselected(wxList
 
 	const int item = event.GetIndex();
 
-#if !defined(__WXMSW__) && wxCHECK_VERSION(3, 2, 1)
+#if !defined(__WXMSW__)
 	if (item == -1) {
 		if (wxGetKeyState(WXK_SHIFT)) {
 			// Sad, so expensive.
@@ -906,7 +906,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::OnItemDeselected(wxList
 				bool selected = GetItemState(m_focusItem, wxLIST_STATE_SELECTED) == wxLIST_STATE_SELECTED;
 				if (selected) {
 					m_selections[m_focusItem] = true;
-					if (m_focusItem >= m_indexMapping.size()) {
+					if (static_cast<size_t>(m_focusItem) >= m_indexMapping.size()) {
 						return;
 					}
 					const int index = m_indexMapping[m_focusItem];
